globals [
  value_prestige ;; This is where the attribute_value of the prestigious agent will be recorded
  CV ;; Coefficient of Variation of the attribute_value
  min_value ;; This is to set the colors, records the minimum attribute value of all turtles
  max_value ;; This is to set the colors, records the maximum attribute value of all turtles
  mean_value ;; This is only for conformism model, stores the mean value of turtles
  ]

turtles-own [
 previous_attribute_value ;; This is because individuals have a memory of 1
 attribute_value;; The new/current attribute value of agents
 prestige ;; 0 or 1. The prestigious agent is given the value 1
 choosing_prestige? ;; Stores a random value to be compared to the probability of choosing prestige
 choosing_conform? ;; Stores a random value to be compared to the probability of conforming to mean
 ]

to setup
  ca
  reset-ticks
  ifelse prestige? = true 
  [ set conformism? false ;; This makes sure that the two different patterns are not mixed by mistake
    ask n-of 40 patches [ sprout 1 ]] ;; This is to reproduce Figure 4
  [ ifelse conformism? = true
    [ ask n-of 40 patches [ sprout 1 ]]
    [ ask n-of 10 patches [ sprout 1 ]]] ;; This is to reproduce Figure 1
  set value_prestige 0
  ask turtles [ set shape "person" 
    set attribute_value random-normal 10 (10 * error_rate / 2) ;; This mimics their first equation giving the inverse of a 
    ;; normal distributon for a specific mean and standard deviation
    ifelse prestige? = true 
    [ set color scale-color blue attribute_value 9.5 10.5 ]
    [ ifelse conformism? = true
      [ set color scale-color red attribute_value 9.5 10.5 ]
      [ set color scale-color green attribute_value 9.5 10.5 ]]] ;; This gives colors in a shade according to their
    ;; attribute-values
end

to go
  if ticks = 401 [ stop ]
  ifelse prestige? = true
  [ set-prestige
    choose ]
  [ ifelse conformism? = true
    [ ask turtles [ conform set color scale-color red attribute_value min_value max_value ]]
    [ ask turtles [ transfer-parent set color scale-color green attribute_value min_value max_value ]]]
  reproduce
  set CV (standard-deviation [ attribute_value ] of turtles / mean [ attribute_value ] of turtles)
  set-current-plot "CV"
  plot CV
  tick
end

to set-values ;; Turtles procedure. This sets the global variables of min and max to keep the color scale updated
   set min_value min [ attribute_value ] of turtles
   set max_value max [ attribute_value ] of turtles
   set mean_value mean [ attribute_value ] of turtles
end

to set-prestige ;; Observer procedure. When prestige is considered, this picks one turtle to be the prestigious one
  ask turtles [ set prestige 0
    set-values 
    set color scale-color blue attribute_value min_value max_value ] ;; This makes sure that at each generation, the prestige is reset to 0 for all
  ask one-of turtles [ set prestige 1 
    set color yellow
    set value_prestige [ attribute_value ] of self ] ;; This chooses one of the turtles and makes it the prestigious one
end

to choose ;; Observer procedure. Turtles chose who they will immitate according to the probability they'll choose the prestigious
  ask turtles [ set choosing_prestige? random 100 ]
  ask turtles
    [ ifelse choosing_prestige? < prestige_% ;; So this sets the number of turtles choosing the prestigious attribute_value
    [ transfer-prestigious ] 
    [ transfer-parent ] ]
end

to conform ;; Turtle procedure. If the random value of the turtle is below the threshold of conformity, the turtle copies the mean attribute of previous generation. Else, they copy the parent
  set-values
  set choosing_conform? random 100
  ifelse choosing_conform? < conformity_%
  [ set previous_attribute_value mean_value ]
  [ set previous_attribute_value attribute_value ]
end

to transfer-parent ;; Turtle procedure. When choosing parent to immitate, this stores the parent's attribute value to be inherited
    set-values
    set previous_attribute_value attribute_value
end

to transfer-prestigious ;; Turtle procedure. When choosing the prestigious individual, this stores its attribute value to be inherited
    set previous_attribute_value value_prestige
end

to reproduce ; This will be used to create a new generation at each tick
  ask turtles [ 
    ;; This is caused by errors in reproducing parent or prestigious behavior
    set attribute_value random-normal previous_attribute_value (previous_attribute_value * (error_rate / 2)) ]
end
@#$#@#$#@
GRAPHICS-WINDOW
234
11
661
303
-1
-1
52.2
1
10
1
1
1
0
1
1
1
0
7
0
4
1
1
1
ticks
30.0

BUTTON
17
10
83
43
NIL
setup\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
113
11
176
44
NIL
go\n
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
15
225
187
258
prestige_%
prestige_%
1
100
3
1
1
NIL
HORIZONTAL

SLIDER
15
270
187
303
error_rate
error_rate
0
0.3
0.03
0.01
1
NIL
HORIZONTAL

PLOT
14
315
214
465
CV
NIL
NIL
0.0
10.0
0.0
0.4
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot CV"

SWITCH
17
98
130
131
prestige?
prestige?
1
1
-1000

SWITCH
17
56
155
89
conformism?
conformism?
1
1
-1000

SLIDER
15
180
187
213
conformity_%
conformity_%
1
100
100
1
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

This is the replication of the model created by Eerkens and Lipo (2005) looking at the impact of error in reproduction of transmitted traits. It has three main states, one in which only the effect of error rate is considered on 10 agents, one in which the authors add a trend towards conformity for 40 agents, and the last one in which some agents have the choice to copy (still with error rate) the most prestigious individual of the generation.

## HOW IT WORKS

This model has three different states

The simplest state, looking only at the effect of error in reproduction, is achieved by having both switches at 'Off'.

The second state, looking at the effect of conformism on a trait variability, can be seen by switching the 'conformism?' switch 'On' and keeping the 'prestige?' 'Off'.

Finally, the third state, looking at the effect of copying a trait from a prestigious individual, is done by switching the 'prestige?' to 'On'. When this is done, the 'conformism?' switch automatically goes 'Off' at setup.

For more info, see ODD protocol of this model

## HOW TO USE IT

Set the switches to the wanted values
- Prestige? 'On' to see the effect of choosing a prestigious individual to copy
- Prestige? 'Off' and conformism? 'On' to see the effect of copying the average values of previous generation on variability

Move the sliders to see how they affect the outcomes

## THINGS TO NOTICE

As the error rate increases, the CV average increases probably exponentially

## THINGS TO TRY

Try different combinations of prob and error rate or conformity and error rate

## EXTENDING THE MODEL

- Adding movement of agents and making them interact in a stronger manner with neighbors
- Creating a layer that register the attribute-value of agents after a generation to see if clusters occur in the landscape
- Add different rates of death and reproduction for different individuals

## CREDITS AND REFERENCES

Eerkens, J.W. and C.P. Lipo, 2005. Cultural transmission, copying errors, and the generation of variation in material culture and the archaeological record, Journal of Anthropological Archaeology, 24(4):316-34
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Replication_Figure4" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>CV</metric>
    <enumeratedValueSet variable="prestige?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conformity?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
      <value value="25"/>
      <value value="50"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="error_rate">
      <value value="0.03"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Replication_Figure1" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>[attribute_value] of turtles</metric>
    <enumeratedValueSet variable="prestige?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conformity?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="error_rate">
      <value value="0.03"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Replication_Figure2" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>CV</metric>
    <enumeratedValueSet variable="prestige?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conformism?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="conformity">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
      <value value="25"/>
      <value value="50"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="error_rate">
      <value value="0.03"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
